@@ -3,7 +3,7 @@ BEGIN {
   $App::DuckPAN::Cmd::Installdeps::AUTHORITY = 'cpan:GETTY';
 }
 {
-  $App::DuckPAN::Cmd::Installdeps::VERSION = '0.054';
+  $App::DuckPAN::Cmd::Installdeps::VERSION = '0.055';
 }
 
 use Moo;
@@ -19,7 +19,7 @@ sub run {
 			"Found a dist.ini, suggesting a Dist::Zilla distribution",
 		);
 		$self->app->perl->cpanminus_install_error
-			if (system("dzil authordeps 2>/dev/null | cpanm"));
+			if (system("dzil authordeps --missing 2>/dev/null | cpanm"));
 		$self->app->perl->cpanminus_install_error
 			if (system("dzil listdeps --missing 2>/dev/null | cpanm"));
 		$self->app->print_text(
